==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/plugins_3rdparty/phylip/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US" sourcelanguage="en">
<context>
    <name>DistMatrixModel</name>
    <message>
        <source>Distance Matrix</source>
        <translation type="vanished">Distance Matrix</translation>
    </message>
    <message>
        <source>Distance matrix model</source>
        <translation type="vanished">Distance matrix model</translation>
    </message>
    <message>
        <source>Gamma distributed rates across sites</source>
        <translation type="vanished">Gamma distributed rates across sites</translation>
    </message>
    <message>
        <source>Coefficient of variation of substitution rate among sites</source>
        <translation type="vanished">Coefficient of variation of substitution rate among sites</translation>
    </message>
    <message>
        <source>Transition/transversion ratio</source>
        <translation type="vanished">Transition/transversion ratio</translation>
    </message>
</context>
<context>
    <name>NeighborJoinWidget</name>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="51"/>
        <source>Distance Matrix</source>
        <translation type="unfinished">Distance Matrix</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="68"/>
        <source>Distance matrix model</source>
        <translation type="unfinished">Distance matrix model</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="88"/>
        <source>Coefficient of variation of substitution rate among sites</source>
        <translation type="unfinished">Coefficient of variation of substitution rate among sites</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="117"/>
        <source>Gamma distributed rates across sites</source>
        <translation type="unfinished">Gamma distributed rates across sites</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="131"/>
        <source>Transition/transversion ratio</source>
        <translation type="unfinished">Transition/transversion ratio</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="176"/>
        <source>Bootstrapping and Consensus Tree</source>
        <translation type="unfinished">Bootstrapping and Consensus Tree</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="185"/>
        <source>Enable bootstrapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="218"/>
        <source>Number of replicates</source>
        <translation type="unfinished">Number of replicates</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="245"/>
        <source>Seed (must be odd)</source>
        <translation type="unfinished">Seed (must be odd)</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="272"/>
        <source>Consensus type</source>
        <translation type="unfinished">Consensus type</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="289"/>
        <source>Fraction</source>
        <translation type="unfinished">Fraction</translation>
    </message>
    <message>
        <location filename="../src/ui/NeighborJoinWidget.ui" line="331"/>
        <source>Display Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SeqBootModel</name>
    <message>
        <source>Bootstrapping and Consensus Tree</source>
        <translation type="vanished">Bootstrapping and Consensus Tree</translation>
    </message>
    <message>
        <source>Number of replicates</source>
        <translation type="vanished">Number of replicates</translation>
    </message>
    <message>
        <source>Seed (must be odd)</source>
        <translation type="vanished">Seed (must be odd)</translation>
    </message>
    <message>
        <source>Consensus type</source>
        <translation type="vanished">Consensus type</translation>
    </message>
    <message>
        <source>Fraction</source>
        <translation type="vanished">Fraction</translation>
    </message>
</context>
<context>
    <name>U2::DistMatrixModelWidget</name>
    <message>
        <source>Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</source>
        <translation type="vanished">Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</translation>
    </message>
</context>
<context>
    <name>U2::NeighborJoinWidget</name>
    <message>
        <location filename="../src/NeighborJoinWidget.cpp" line="147"/>
        <source>Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</source>
        <translation type="unfinished">Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.cpp" line="158"/>
        <source>Seed must be odd</source>
        <translation type="unfinished">Seed must be odd</translation>
    </message>
</context>
<context>
    <name>U2::PhylipPlugin</name>
    <message>
        <location filename="../src/PhylipPlugin.cpp" line="59"/>
        <source>PHYLIP</source>
        <translation>PHYLIP</translation>
    </message>
    <message>
        <location filename="../src/PhylipPlugin.cpp" line="59"/>
        <source>PHYLIP (the PHYLogeny Inference Package) is a package of programs for inferring phylogenies (evolutionary trees). Original version at: http://evolution.genetics.washington.edu/phylip.html</source>
        <translation>PHYLIP (the PHYLogeny Inference Package) is a package of programs for inferring phylogenies (evolutionary trees). Original version at: http://evolution.genetics.washington.edu/phylip.html</translation>
    </message>
</context>
<context>
    <name>U2::SeqBootModelWidget</name>
    <message>
        <source>Seed must be odd</source>
        <translation type="vanished">Seed must be odd</translation>
    </message>
</context>
</TS>

==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins_3rdparty/phylip/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US" sourcelanguage="en">
<context>
    <name>DistMatrixModel</name>
    <message>
        <source>Distance Matrix</source>
        <translation type="vanished">Distance Matrix</translation>
    </message>
    <message>
        <source>Distance matrix model</source>
        <translation type="vanished">Distance matrix model</translation>
    </message>
    <message>
        <source>Gamma distributed rates across sites</source>
        <translation type="vanished">Gamma distributed rates across sites</translation>
    </message>
    <message>
        <source>Coefficient of variation of substitution rate among sites</source>
        <translation type="vanished">Coefficient of variation of substitution rate among sites</translation>
    </message>
    <message>
        <source>Transition/transversion ratio</source>
        <translation type="vanished">Transition/transversion ratio</translation>
    </message>
</context>
<context>
    <name>NeighborJoinWidget</name>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="51"/>
        <source>Distance Matrix</source>
        <translation type="unfinished">Distance Matrix</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="68"/>
        <source>Distance matrix model</source>
        <translation type="unfinished">Distance matrix model</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="88"/>
        <source>Coefficient of variation of substitution rate among sites</source>
        <translation type="unfinished">Coefficient of variation of substitution rate among sites</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="117"/>
        <source>Gamma distributed rates across sites</source>
        <translation type="unfinished">Gamma distributed rates across sites</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="131"/>
        <source>Transition/transversion ratio</source>
        <translation type="unfinished">Transition/transversion ratio</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="176"/>
        <source>Bootstrapping and Consensus Tree</source>
        <translation type="unfinished">Bootstrapping and Consensus Tree</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="185"/>
        <source>Enable bootstrapping</source>
        <translation>Enable bootstrapping</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="218"/>
        <source>Number of replicates</source>
        <translation type="unfinished">Number of replicates</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="245"/>
        <source>Seed (must be odd)</source>
        <translation type="unfinished">Seed (must be odd)</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="272"/>
        <source>Consensus type</source>
        <translation type="unfinished">Consensus type</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="289"/>
        <source>Fraction</source>
        <translation type="unfinished">Fraction</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.ui" line="331"/>
        <source>Display Options</source>
        <translation>Display Options</translation>
    </message>
</context>
<context>
    <name>SeqBootModel</name>
    <message>
        <source>Bootstrapping and Consensus Tree</source>
        <translation type="vanished">Bootstrapping and Consensus Tree</translation>
    </message>
    <message>
        <source>Number of replicates</source>
        <translation type="vanished">Number of replicates</translation>
    </message>
    <message>
        <source>Seed (must be odd)</source>
        <translation type="vanished">Seed (must be odd)</translation>
    </message>
    <message>
        <source>Consensus type</source>
        <translation type="vanished">Consensus type</translation>
    </message>
    <message>
        <source>Fraction</source>
        <translation type="vanished">Fraction</translation>
    </message>
</context>
<context>
    <name>U2::DistMatrixModelWidget</name>
    <message>
        <source>Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</source>
        <translation type="vanished">Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</translation>
    </message>
</context>
<context>
    <name>U2::NeighborJoinWidget</name>
    <message>
        <location filename="../src/NeighborJoinWidget.cpp" line="147"/>
        <source>Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</source>
        <translation type="unfinished">Probably, for that alignment there is no enough memory to run PHYLIP dnadist module.The module will require more than %1 MB in the estimation.
It could cause an error. Do you want to continue?</translation>
    </message>
    <message>
        <location filename="../src/NeighborJoinWidget.cpp" line="158"/>
        <source>Seed must be odd</source>
        <translation type="unfinished">Seed must be odd</translation>
    </message>
</context>
<context>
    <name>U2::PhylipCmdlineTask</name>
    <message>
        <location filename="../src/PhylipCmdlineTask.cpp" line="52"/>
        <source>PHYLIP command line wrapper task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/PhylipCmdlineTask.cpp" line="74"/>
        <source>No tree objects found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::PhylipPlugin</name>
    <message>
        <location filename="../src/PhylipPlugin.cpp" line="50"/>
        <source>PHYLIP</source>
        <translation>PHYLIP</translation>
    </message>
    <message>
        <location filename="../src/PhylipPlugin.cpp" line="50"/>
        <source>PHYLIP (the PHYLogeny Inference Package) is a package of programs for inferring phylogenies (evolutionary trees). Original version at: http://evolution.genetics.washington.edu/phylip.html</source>
        <translation>PHYLIP (the PHYLogeny Inference Package) is a package of programs for inferring phylogenies (evolutionary trees). Original version at: http://evolution.genetics.washington.edu/phylip.html</translation>
    </message>
</context>
<context>
    <name>U2::PhylipTask</name>
    <message>
        <location filename="../src/PhylipTask.cpp" line="33"/>
        <source>PHYLIP task</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::SeqBootModelWidget</name>
    <message>
        <source>Seed must be odd</source>
        <translation type="vanished">Seed must be odd</translation>
    </message>
</context>
</TS>
